@@ -5,14 +5,15 @@ import getpass
 import os
 import shutil
 import sys
+from typing import Any
 
 
-def run(install):
+def run(install: Any) -> None:
     """Runs all post install hooks."""
     _copy_sh_ext(install)
 
 
-def _copy_sh_ext(install):
+def _copy_sh_ext(install: Any) -> None:
     """Copy shell extension to funky config directory."""
     this_dir = os.path.dirname(os.path.realpath(__file__))
     root = install.root if install.root else ''
@@ -36,14 +37,10 @@ def _copy_sh_ext(install):
     shutil.copyfile(src, dest)
 
 
-def _create_dir(directory):
+def _create_dir(directory: str) -> None:
     """Create directory."""
     try:
         os.makedirs(directory)
     except OSError as e:
         if e.errno != errno.EEXIST:
             return
-
-
-if __name__ == "__main__":
-    run()
